@@ -1,40 +1,8 @@
-#!/usr/bin/env python
-
-## 
- # ###################################################################
- #  FiPy - Python-based finite volume PDE solver
- # 
- #  FILE: "input2D.py"
- #
- #  Author: Jonathan Guyer <guyer@nist.gov>
- #  Author: Daniel Wheeler <daniel.wheeler@nist.gov>
- #    mail: NIST
- #     www: http://ctcms.nist.gov
- #  
- # ========================================================================
- # This software was developed at the National Institute of Standards
- # and Technology by employees of the Federal Government in the course
- # of their official duties.  Pursuant to title 17 Section 105 of the
- # United States Code this software is not subject to copyright
- # protection and is in the public domain.  FiPy is an experimental
- # system.  NIST assumes no responsibility whatsoever for its use by
- # other parties, and makes no guarantees, expressed or implied, about
- # its quality, reliability, or any other characteristic.  We would
- # appreciate acknowledgement if the software is used.
- # 
- # This software can be redistributed and/or modified freely
- # provided that any derivative works bear some notice that they are
- # derived from it, and any modified versions bear some notice that
- # they have been modified.
- # ========================================================================
- #  
- # ###################################################################
- ##
-
 r"""
 Solves the Cahn-Hilliard problem in a 3D cube
 
->>> from fipy import *
+>>> from fipy import CellVariable, Grid3D, Viewer, GaussianNoiseVariable, TransientTerm, DiffusionTerm, DefaultSolver
+>>> from fipy.tools import numerix
 
 The only difference from :mod:`examples.cahnHilliard.mesh2D` is the
 declaration of ``mesh``.
@@ -57,12 +25,12 @@ We start the problem with random fluctuations about :math:`\phi = 1/2`
 >>> if __name__ == "__main__":
 ...     viewer = Viewer(vars=(phi,), datamin=0., datamax=1.)
 
-For :term:`FiPy`, we need to perform the partial derivative 
-:math:`\partial f/\partial \phi`    
+For :term:`FiPy`, we need to perform the partial derivative
+:math:`\partial f/\partial \phi`
 manually and then put the equation in the canonical
 form by decomposing the spatial derivatives
 so that each :class:`~fipy.terms.term.Term` is of a single, even order:
-    
+
 .. math::
 
    \frac{\partial \phi}{\partial t}
@@ -106,12 +74,13 @@ evolution of their problem.
    :align: center
    :alt: snapshot of Cahn-Hilliard phase separation in 3D with cutaway
 """
+from __future__ import unicode_literals
 __docformat__ = 'restructuredtext'
 
+from fipy import input
+
 if __name__ == '__main__':
     import fipy.tests.doctestPlus
     exec(fipy.tests.doctestPlus._getScript())
-    
-    raw_input('finished')
-
 
+    input('finished')
