@@ -1,19 +1,20 @@
+from __future__ import unicode_literals
 import sys
 
 try:
     from mayavi import mlab
-except ImportError, e:
+except ImportError as e:
     from enthought.mayavi import mlab
 
 from fipy.viewers.mayaviViewer.mayaviDaemon import MayaviDaemon
 
 class SphereDaemon(MayaviDaemon):
-    
+
     def view_data(self):
-        """Sets up the mayavi pipeline for the visualization.
+        """Sets up the Mayavi pipeline for the visualization.
         """
         var = mlab.pipeline.set_active_attribute(self.cellsource, cell_scalars=r"$\phi$")
-        
+
         if hasattr(mlab.pipeline, "data_set_clipper"):
             clip = mlab.pipeline.data_set_clipper(var)
 
@@ -31,9 +32,9 @@ class SphereDaemon(MayaviDaemon):
         s = mlab.pipeline.surface(clip, vmin=self.datamin, vmax=self.datamax, colormap='hot')
         s.module_manager.scalar_lut_manager.show_scalar_bar = True
 
-        
+
 def main(argv=None):
-    """Simple helper to start up the mayavi application.  This returns
+    """Simple helper to start up the Mayavi application.  This returns
     the running application."""
     m = SphereDaemon()
     m.main(argv)
