@@ -1,38 +1,4 @@
-#!/usr/bin/env python
-
-## -*-Pyth-*-
- # ###################################################################
- #  FiPy - Python-based finite volume PDE solver
- # 
- #  FILE: "tri2D.py"
- #
- #  Author: Alexander Mont <alexander.mont@nist.gov>
- #  Author: Jonathan Guyer <guyer@nist.gov>
- #  Author: Daniel Wheeler <daniel.wheeler@nist.gov>
- #  Author: James Warren   <jwarren@nist.gov>
- #    mail: NIST
- #     www: http://www.ctcms.nist.gov/fipy/
- #  
- # ========================================================================
- # This software was developed at the National Institute of Standards
- # and Technology by employees of the Federal Government in the course
- # of their official duties.  Pursuant to title 17 Section 105 of the
- # United States Code this software is not subject to copyright
- # protection and is in the public domain.  FiPy is an experimental
- # system.  NIST assumes no responsibility whatsoever for its use by
- # other parties, and makes no guarantees, expressed or implied, about
- # its quality, reliability, or any other characteristic.  We would
- # appreciate acknowledgement if the software is used.
- # 
- # This software can be redistributed and/or modified freely
- # provided that any derivative works bear some notice that they are
- # derived from it, and any modified versions bear some notice that
- # they have been modified.
- # ========================================================================
- #  
- # ###################################################################
- ##
-
+from __future__ import unicode_literals
 __docformat__ = "restructuredtext"
 
 from fipy.tools import numerix
@@ -44,15 +10,17 @@ from fipy.meshes.representations.gridRepresentation import _Grid2DRepresentation
 from fipy.meshes.topologies.meshTopology import _Mesh2DTopology
 
 __all__ = ["Tri2D"]
+from future.utils import text_to_native_str
+__all__ = [text_to_native_str(n) for n in __all__]
 
 class Tri2D(Mesh2D):
     """
     This class creates a mesh made out of triangles.  It does this by
     starting with a standard Cartesian mesh (`Grid2D`) and dividing each cell
-    in that mesh (hereafter referred to as a 'box') into four equal
+    in that mesh (hereafter referred to as a "box") into four equal
     parts with the dividing lines being the diagonals.
     """
-    
+
     def __init__(self, dx = 1., dy = 1., nx = 1, ny = 1,
                  _RepresentationClass=_Grid2DRepresentation, _TopologyClass=_Mesh2DTopology):
         """
@@ -61,22 +29,25 @@ class Tri2D(Mesh2D):
         with the vertices at the corners of boxes and then the vertices at the
         centers of boxes.  Cells on the right of boxes are numbered first, then
         cells on the top of boxes, then cells on the left of boxes, then cells
-        on the bottom of boxes.  Within each of the 'sub-categories' in the
+        on the bottom of boxes.  Within each of the "sub-categories" in the
         above, the vertices, cells and faces are numbered in the usual way.
-        
-        :Parameters:
-          - `dx, dy`: The X and Y dimensions of each 'box'. 
-            If `dx` <> `dy`, the line segments connecting the cell 
+
+        Parameters
+        ----------
+        float dx, dy : float
+            The X and Y dimensions of each "box".
+            If `dx` <> `dy`, the line segments connecting the cell
             centers will not be orthogonal to the faces.
-          - `nx, ny`: The number of boxes in the X direction and the Y direction. 
-            The total number of boxes will be equal to `nx * ny`, and the total 
+        int nx, ny : int
+            The number of boxes in the X direction and the Y direction.
+            The total number of boxes will be equal to `nx * ny`, and the total
             number of cells will be equal to `4 * nx * ny`.
         """
-        
+
         self.args = {
-            'dx': dx, 
-            'dy': dy, 
-            'nx': nx, 
+            'dx': dx,
+            'dy': dy,
+            'nx': nx,
             'ny': ny
         }
 
@@ -86,23 +57,23 @@ class Tri2D(Mesh2D):
         self.numberOfHorizontalFaces   = self.nx * (self.ny + 1)
         self.numberOfVerticalFaces     = self.ny * (self.nx + 1)
         self.numberOfEachDiagonalFaces = self.nx * self.ny
-        
+
         self.dx  = PhysicalField(value = dx)
         scale    = PhysicalField(value = 1, unit = self.dx.unit)
         self.dx /= scale
-        
+
         self.dy = PhysicalField(value = dy)
         if self.dy.unit.isDimensionless():
             self.dy = dy
         else:
             self.dy /= scale
-        
+
         self.numberOfCornerVertices = (self.nx + 1) * (self. ny + 1)
         self.numberOfCenterVertices = self.nx * self.ny
         self.numberOfTotalVertices  = self.numberOfCornerVertices + self.numberOfCenterVertices
-        
+
         self.offset = (0, 0)
-        
+
         vertices = self._createVertices()
         faces    = self._createFaces()
 
@@ -115,7 +86,7 @@ class Tri2D(Mesh2D):
         self.scale = scale
 
     def _createVertices(self):
-        
+
         x = numerix.arange(self.nx + 1) * self.dx
         y = numerix.arange(self.ny + 1) * self.dy
         x = numerix.resize(x, (self.numberOfCornerVertices,))
@@ -127,12 +98,10 @@ class Tri2D(Mesh2D):
         y = numerix.repeat(y, self.nx)
         boxCenters = numerix.array((x, y))
         return numerix.concatenate((boxCorners, boxCenters), axis=1)
-    
+
     def _createFaces(self):
-        """
-        v1, v2 refer to the cells.
-        Horizontel faces are first
-        """
+        ## v1, v2 refer to the cells.
+        ## Horizontal faces are first
         v1 = numerix.arange(self.numberOfCornerVertices)
         v2 = v1 + 1
         horizontalFaces = vector.prune(numerix.array((v1, v2)), self.nx + 1, self.nx, axis=1)
@@ -153,7 +122,7 @@ class Tri2D(Mesh2D):
         verticalFaces[1, ::(self.nx + 1)] = tmp[1, ::(self.nx + 1)]
 
         ## do the center ones now
-        
+
         cellCenters = numerix.arange(self.numberOfCornerVertices, self.numberOfTotalVertices)
         lowerLefts = vector.prune(numerix.arange(self.numberOfCornerVertices - (self.nx + 1)), self.nx + 1, self.nx)
         lowerRights = lowerLefts + 1
@@ -166,10 +135,8 @@ class Tri2D(Mesh2D):
         return numerix.concatenate((horizontalFaces, verticalFaces, lowerLeftFaces, lowerRightFaces, upperLeftFaces, upperRightFaces), axis=1)
 
     def _createCells(self):
-        """
-        cells = (f1, f2, f3, f4) going anticlockwise.
-        f1 etc. refer to the faces
-        """
+        ## cells = (f1, f2, f3, f4) going anticlockwise.
+        ## f1 etc. refer to the faces
         bottomFaces = numerix.arange(0, self.numberOfHorizontalFaces - self.nx)
         topFaces = numerix.arange(self.nx, self.numberOfHorizontalFaces)
         leftFaces = vector.prune(numerix.arange(self.numberOfHorizontalFaces, self.numberOfHorizontalFaces + self.numberOfVerticalFaces), self.nx + 1, self.nx)
@@ -184,18 +151,18 @@ class Tri2D(Mesh2D):
         topOfBoxCells = numerix.array([topFaces, upperLeftDiagonalFaces, upperRightDiagonalFaces])
         leftOfBoxCells = numerix.array([leftFaces, lowerLeftDiagonalFaces, upperLeftDiagonalFaces])
         return numerix.concatenate((rightOfBoxCells, topOfBoxCells, leftOfBoxCells, bottomOfBoxCells), axis=1)
-        
+
     @property
     def physicalShape(self):
-        """Return physical dimensions of Grid2D.
+        """Return physical dimensions of `Grid2D`.
         """
-        return PhysicalField(value = (self.nx * self.dx * self.scale, 
+        return PhysicalField(value = (self.nx * self.dx * self.scale,
                                       self.ny * self.dy * self.scale))
 
     @property
     def _meshSpacing(self):
-        return numerix.array((self.dx,self.dy))[...,numerix.newaxis]
-    
+        return numerix.array((self.dx, self.dy))[..., numerix.newaxis]
+
     @property
     def shape(self):
         return (self.nx, self.ny)
@@ -203,7 +170,7 @@ class Tri2D(Mesh2D):
     @property
     def _isOrthogonal(self):
         return True
-    
+
 ## pickling
 
     def _test(self):
@@ -215,16 +182,16 @@ class Tri2D(Mesh2D):
             >>> dy = 2.
             >>> nx = 3
             >>> ny = 2
-            
-            >>> mesh = Tri2D(nx = nx, ny = ny, dx = dx, dy = dy)     
-            
+
+            >>> mesh = Tri2D(nx = nx, ny = ny, dx = dx, dy = dy)
+
             >>> vertices = numerix.array(((0.0, 0.5, 1.0, 1.5, 0.0, 0.5, 1.0, 1.5, 0.0, 0.5, 1.0, 1.5, 0.25, 0.75, 1.25, 0.25, 0.75, 1.25),
             ...                           (0.0, 0.0, 0.0, 0.0, 2.0, 2.0, 2.0, 2.0, 4.0, 4.0, 4.0, 4.0, 1.0,  1.0,  1.0,  3.0,  3.0,  3.0)))
-            
+
             >>> from fipy.tools import numerix
             >>> numerix.allequal(vertices, mesh._createVertices())
             1
-        
+
             >>> faces = numerix.array(((1, 2, 3, 4, 5, 6, 8,  9, 10, 0, 5, 6, 7, 4, 9, 10, 11, 12, 13, 14, 15, 16, 17,  1,  2,  3,  5,  6,  7, 12, 13, 14, 15, 16, 17, 12, 13, 14, 15, 16, 17),
             ...                        (0, 1, 2, 5, 6, 7, 9, 10, 11, 4, 1, 2, 3, 8, 5,  6,  7,  0,  1,  2,  4,  5,  6, 12, 13, 14, 15, 16, 17,  4,  5,  6,  8,  9, 10,  5,  6,  7,  9, 10, 11)))
             >>> numerix.allequal(faces, mesh._createFaces())
@@ -236,14 +203,14 @@ class Tri2D(Mesh2D):
             >>> numerix.allequal(cells, mesh._createCells())
             1
 
-            >>> externalFaces = numerix.array((0, 1, 2, 6, 7, 8, 9 , 12, 13, 16))
-            >>> print numerix.allequal(externalFaces, 
-            ...                        numerix.nonzero(mesh.exteriorFaces))
+            >>> externalFaces = numerix.array((0, 1, 2, 6, 7, 8, 9, 12, 13, 16))
+            >>> print(numerix.allequal(externalFaces,
+            ...                        numerix.nonzero(mesh.exteriorFaces)))
             1
 
             >>> internalFaces = numerix.array((3, 4, 5, 10, 11, 14, 15, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40))
-            >>> print numerix.allequal(internalFaces, 
-            ...                        numerix.nonzero(mesh.interiorFaces))
+            >>> print(numerix.allequal(internalFaces,
+            ...                        numerix.nonzero(mesh.interiorFaces)))
             1
 
             >>> from fipy.tools.numerix import MA
@@ -251,33 +218,33 @@ class Tri2D(Mesh2D):
             ...                                 (-1, -1, -1, 21, 22, 23, -1, -1, -1, -1, 13, 14, -1, -1, 16, 17, -1, 18, 19, 20, 21, 22, 23, 18, 19, 20, 21, 22, 23, 12, 13, 14, 15, 16, 17,  6,  7,  8,  9, 10, 11)), -1)
             >>> numerix.allequal(faceCellIds, mesh.faceCellIDs)
             1
-            
-            >>> d = (numerix.sqrt((dx*dx)+(dy*dy))) / 2.0 ## length of diagonal edges  
+
+            >>> d = (numerix.sqrt((dx*dx)+(dy*dy))) / 2.0 ## length of diagonal edges
             >>> faceAreas = numerix.array((0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5,
             ...                            2, 2, 2, 2, 2, 2, 2, 2,
             ...                            d, d, d, d, d, d, d, d, d, d, d, d, d, d, d, d, d, d, d, d, d, d, d, d))
             >>> numerix.allclose(faceAreas, mesh._faceAreas, atol = 1e-10, rtol = 1e-10)
             1
-            
+
             >>> faceCoords = numerix.take(vertices, faces, axis=1)
-            >>> faceCenters = (faceCoords[...,0,:] + faceCoords[...,1,:]) / 2.
-            >>> print numerix.allclose(faceCenters, mesh.faceCenters, atol = 1e-10, rtol = 1e-10)
+            >>> faceCenters = (faceCoords[..., 0,:] + faceCoords[..., 1,:]) / 2.
+            >>> print(numerix.allclose(faceCenters, mesh.faceCenters, atol = 1e-10, rtol = 1e-10))
             True
 
             >>> xc = dy  / numerix.sqrt((dx * dx) + (dy * dy))
             >>> yc = dx  / numerix.sqrt((dx * dx) + (dy * dy))
-            
-            >>> faceNormals = numerix.array((( 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,-1.0, 1.0, 1.0, 1.0,-1.0, 1.0, 1.0, 1.0, xc, xc, xc, xc, xc, xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc),
-            ...                              (-1.0,-1.0,-1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc, yc, yc, yc, yc, yc, yc)))
+
+            >>> faceNormals = numerix.array((( 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.0, 1.0, 1.0, 1.0, -1.0, 1.0, 1.0, 1.0, xc, xc, xc, xc, xc, xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc),
+            ...                              (-1.0, -1.0, -1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, yc, yc, yc, yc, yc, yc)))
             >>> numerix.allclose(faceNormals, mesh.faceNormals, atol = 1e-10, rtol = 1e-10)
             1
 
-            >>> cellToFaceOrientations = numerix.array((( 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,-1,-1, 1,-1,-1, 1, 1, 1,-1,-1,-1),
-            ...                                         ( 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,-1,-1,-1,-1,-1,-1),
-            ...                                         ( 1, 1, 1, 1, 1, 1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1)))
+            >>> cellToFaceOrientations = numerix.array((( 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, -1, -1, 1, -1, -1, 1, 1, 1, -1, -1, -1),
+            ...                                         ( 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, -1, -1, -1, -1, -1, -1),
+            ...                                         ( 1, 1, 1, 1, 1, 1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1)))
             >>> numerix.allequal(cellToFaceOrientations, mesh._cellToFaceOrientations)
             1
-                                             
+
             >>> cellVolumes = numerix.array((0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25,
             ...                              0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25,
             ...                              0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25))
@@ -288,16 +255,16 @@ class Tri2D(Mesh2D):
             >>> cellCenters = numerix.array(((  5*sixth, 11*sixth, 17*sixth,  5*sixth, 11*sixth, 17*sixth,      0.5,      1.5,      2.5,      0.5,      1.5,      2.5,  1*sixth,  7*sixth, 13*sixth,  1*sixth,  7*sixth, 13*sixth,      0.5,      1.5,      2.5,      0.5,      1.5,      2.5),
             ...                              (      0.5,      0.5,      0.5,      1.5,      1.5,      1.5,  5*sixth,  5*sixth,  5*sixth, 11*sixth, 11*sixth, 11*sixth,      0.5,      0.5,      0.5,      1.5,      1.5,      1.5,  1*sixth,  1*sixth,  1*sixth,  7*sixth,  7*sixth,  7*sixth)))
             >>> cellCenters *= numerix.array([[dx], [dy]])
-            >>> print numerix.allclose(cellCenters, mesh.cellCenters, atol = 1e-10, rtol = 1e-10)
+            >>> print(numerix.allclose(cellCenters, mesh.cellCenters, atol = 1e-10, rtol = 1e-10))
             True
-                                              
+
             >>> yd = numerix.sqrt(((dx/12.0)*(dx/12.0)) + ((dy/ 4.0)*(dy/ 4.0)))
             >>> xd = numerix.sqrt(((dx/ 4.0)*(dx/ 4.0)) + ((dy/12.0)*(dy/12.0)))
             >>> faceToCellDistances = MA.masked_values(((dy/6.0, dy/6.0, dy/6.0, dy/6.0, dy/6.0, dy/6.0,  dy/6.0, dy/6.0, dy/6.0, dx/6.0, dx/6.0, dx/6.0, dx/6.0, dx/6.0, dx/6.0, dx/6.0, dx/6.0,     yd,     yd,     yd,     yd,     yd,     yd,     yd,     yd,     yd,     yd,     yd,     yd,     xd,     xd,     xd,     xd,     xd,     xd,     yd,     yd,     yd,     yd,     yd,     yd),
             ...                                         (    -1,     -1,     -1, dy/6.0, dy/6.0, dy/6.0,      -1,     -1,     -1,     -1, dx/6.0, dx/6.0,     -1,     -1, dx/6.0, dx/6.0,     -1,     xd,     xd,     xd,     xd,     xd,     xd,     xd,     xd,     xd,     xd,     xd,     xd,     yd,     yd,     yd,     yd,     yd,     yd,     xd,     xd,     xd,     xd,     xd,     xd)), -1)
             >>> numerix.allclose(faceToCellDistances, mesh._faceToCellDistances, atol = 1e-10, rtol = 1e-10)
             1
-                                              
+
             >>> dd = numerix.sqrt((dx*dx)+(dy*dy)) / 3.0
             >>> cellDistances = numerix.array((dy/6.0, dy/6.0, dy/6.0, dy/3.0, dy/3.0, dy/3.0, dy/6.0, dy/6.0, dy/6.0,
             ...                                dx/6.0, dx/3.0, dx/3.0, dx/6.0, dx/6.0, dx/3.0, dx/3.0, dx/6.0,
@@ -305,7 +272,7 @@ class Tri2D(Mesh2D):
             ...                                dd, dd, dd, dd, dd, dd, dd, dd, dd, dd, dd, dd))
             >>> numerix.allclose(cellDistances, mesh._cellDistances, atol = 1e-10, rtol = 1e-10)
             1
-            
+
             >>> faceToCellDistanceRatios = faceToCellDistances[0] / cellDistances
             >>> numerix.allclose(faceToCellDistanceRatios, mesh._faceToCellDistanceRatio, atol = 1e-10, rtol = 1e-10)
             1
@@ -314,8 +281,8 @@ class Tri2D(Mesh2D):
             >>> numerix.allclose(areaProjections, mesh._areaProjections, atol = 1e-10, rtol = 1e-10)
             1
 
-            >>> tangents1 = numerix.array(((1.0, 1.0, 1.0,-1.0,-1.0,-1.0,-1.0,-1.0,-1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc, -yc, -yc, -yc, -yc, -yc, -yc),
-            ...                            (0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,-1.0, 1.0, 1.0, 1.0,-1.0, 1.0, 1.0, 1.0,  xc,  xc,  xc,  xc,  xc,  xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc)))
+            >>> tangents1 = numerix.array(((1.0, 1.0, 1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc,  yc, -yc, -yc, -yc, -yc, -yc, -yc),
+            ...                            (0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.0, 1.0, 1.0, 1.0, -1.0, 1.0, 1.0, 1.0,  xc,  xc,  xc,  xc,  xc,  xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc)))
             >>> numerix.allclose(tangents1, mesh._faceTangents1, atol = 1e-10, rtol = 1e-10)
             1
 
@@ -344,11 +311,11 @@ class Tri2D(Mesh2D):
             1
 
             >>> cellNormals = numerix.array((((  1,  1,  1,  1,  1,  1,  0,  0,  0,  0,  0,  0, -1, -1, -1, -1, -1, -1,  0,  0,  0,  0,  0,  0),
-            ...                               (-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc,-xc, xc, xc, xc, xc, xc, xc,-xc,-xc,-xc,-xc,-xc,-xc),
-            ...                               (-xc,-xc,-xc,-xc,-xc,-xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc)),
+            ...                               (-xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, -xc, xc, xc, xc, xc, xc, xc, -xc, -xc, -xc, -xc, -xc, -xc),
+            ...                               (-xc, -xc, -xc, -xc, -xc, -xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc, xc)),
             ...                              ((  0,  0,  0,  0,  0,  0,  1,  1,  1,  1,  1,  1,  0,  0,  0,  0,  0,  0, -1, -1, -1, -1, -1, -1),
-            ...                               (-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc,-yc, yc, yc, yc, yc, yc, yc),
-            ...                               ( yc, yc, yc, yc, yc, yc,-yc,-yc,-yc,-yc,-yc,-yc, yc, yc, yc, yc, yc, yc, yc, yc, yc, yc, yc, yc))))
+            ...                               (-yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, -yc, yc, yc, yc, yc, yc, yc),
+            ...                               ( yc, yc, yc, yc, yc, yc, -yc, -yc, -yc, -yc, -yc, -yc, yc, yc, yc, yc, yc, yc, yc, yc, yc, yc, yc, yc))))
             >>> numerix.allclose(cellNormals, mesh._cellNormals, atol = 1e-10, rtol = 1e-10)
             1
 
@@ -370,25 +337,26 @@ class Tri2D(Mesh2D):
             ...                                tmp2, tmp2 + 1, tmp2 + 2, tmp2 + 3 + tmp5, tmp2 + 4 + tmp5, tmp2 + 5 + tmp5,
             ...                                tmp3, tmp3 + 1, tmp3 + 2, tmp3 + 3 + tmp5, tmp3 + 4 + tmp5, tmp3 + 5 + tmp5,
             ...                                tmp4, tmp4 + 1, tmp4 + 2, tmp4 + 3 + tmp5, tmp4 + 4 + tmp5, tmp4 + 5 + tmp5))
-            >>> cellVertexIDs = cellVertexIDs.swapaxes(0,1)
+            >>> cellVertexIDs = cellVertexIDs.swapaxes(0, 1)
             >>> numerix.allclose(mesh._cellVertexIDs, cellVertexIDs)
             1
-            
 
-            >>> from fipy.tools import dump            
-            >>> (f, filename) = dump.write(mesh, extension = '.gz')            
+
+            >>> from fipy.tools import dump
+            >>> (f, filename) = dump.write(mesh, extension = '.gz')
             >>> unpickledMesh = dump.read(filename, f)
 
-            >>> print numerix.allequal(mesh.cellCenters, unpickledMesh.cellCenters)
+            >>> print(numerix.allequal(mesh.cellCenters, unpickledMesh.cellCenters))
             True
         """
 
 ## test test test
-        
-def _test(): 
+
+def _test():
     import fipy.tests.doctestPlus
     return fipy.tests.doctestPlus.testmod()
-    
-if __name__ == "__main__": 
-    _test() 
+
+if __name__ == "__main__":
+    _test()
+
 
