@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 from fipy.solvers.pysparse.linearCGSSolver import *
 from fipy.solvers.pysparse.linearPCGSolver import *
 from fipy.solvers.pysparse.linearGMRESSolver import *
@@ -15,7 +16,9 @@ __all__ = ["DefaultSolver",
            "DummySolver",
            "DefaultAsymmetricSolver",
            "GeneralSolver"]
-           
+from future.utils import text_to_native_str
+__all__ = [text_to_native_str(n) for n in __all__]
+
 __all__.extend(linearCGSSolver.__all__)
 __all__.extend(linearPCGSolver.__all__)
 __all__.extend(linearGMRESSolver.__all__)
