@@ -1,37 +1,5 @@
-#!/usr/bin/env python
-
-## -*-Pyth-*-
- # ###################################################################
- #  FiPy - Python-based finite volume PDE solver
- # 
- #  FILE: "baseConvectionTerm.py"
- #
- #  Author: Jonathan Guyer <guyer@nist.gov>
- #  Author: Daniel Wheeler <daniel.wheeler@nist.gov>
- #  Author: James Warren   <jwarren@nist.gov>
- #    mail: NIST
- #     www: http://www.ctcms.nist.gov/fipy/
- #  
- # ========================================================================
- # This software was developed at the National Institute of Standards
- # and Technology by employees of the Federal Government in the course
- # of their official duties.  Pursuant to title 17 Section 105 of the
- # United States Code this software is not subject to copyright
- # protection and is in the public domain.  FiPy is an experimental
- # system.  NIST assumes no responsibility whatsoever for its use by
- # other parties, and makes no guarantees, expressed or implied, about
- # its quality, reliability, or any other characteristic.  We would
- # appreciate acknowledgement if the software is used.
- # 
- # This software can be redistributed and/or modified freely
- # provided that any derivative works bear some notice that they are
- # derived from it, and any modified versions bear some notice that
- # they have been modified.
- # ========================================================================
- #  
- # ###################################################################
- ##
-
+from __future__ import division
+from __future__ import unicode_literals
 __docformat__ = 'restructuredtext'
 
 __all__ = []
@@ -51,7 +19,7 @@ class _AbstractConvectionTerm(FaceTerm):
     def __init__(self, coeff=1.0, var=None):
         """
         Create a `_AbstractConvectionTerm` object.
-        
+
             >>> from fipy import *
             >>> m = Grid1D(nx = 2)
             >>> cv = CellVariable(mesh = m)
@@ -92,18 +60,19 @@ class _AbstractConvectionTerm(FaceTerm):
             >>> __ConvectionTerm(coeff=vfv2)
             __ConvectionTerm(coeff=FaceVariable(value=array([[ 0.,  0.,  0.,  0.,  0.,  0.,  0.],
                    [ 0.,  0.,  0.,  0.,  0.,  0.,  0.]]), mesh=UniformGrid2D(dx=1.0, nx=2, dy=1.0, ny=1)))
-            >>> (TransientTerm() - ExplicitUpwindConvectionTerm(coeff = ((0,),(0,)))).solve(var=cv2, solver=DummySolver(), dt=1.)
-            >>> (TransientTerm() - ExplicitUpwindConvectionTerm(coeff = (0,0))).solve(var=cv2, solver=DummySolver(), dt=1.)
+            >>> (TransientTerm() - ExplicitUpwindConvectionTerm(coeff = ((0,), (0,)))).solve(var=cv2, solver=DummySolver(), dt=1.)
+            >>> (TransientTerm() - ExplicitUpwindConvectionTerm(coeff = (0, 0))).solve(var=cv2, solver=DummySolver(), dt=1.)
 
-        
-        :Parameters:
-          - `coeff` : The `Term`'s coefficient value.
+
+        Parameters
+        ----------
+        coeff : The `Term`'s coefficient value.
         """
         if self.__class__ is _AbstractConvectionTerm:
             raise AbstractBaseClassError
-            
+
         self.stencil = None
-        
+
         if isinstance(coeff, _MeshVariable) and coeff.rank < 1:
             raise VectorCoeffError
 
@@ -111,7 +80,7 @@ class _AbstractConvectionTerm(FaceTerm):
             coeff = coeff.arithmeticFaceValue
 
         FaceTerm.__init__(self, coeff=coeff, var=var)
-        
+
     def _calcGeomCoeff(self, var):
         mesh = var.mesh
 
@@ -120,13 +89,13 @@ class _AbstractConvectionTerm(FaceTerm):
 
             if shape != () and shape != (1,) and shape[-1] == 1:
                 shape = shape[:-1]
-            
+
             self.coeff = FaceVariable(mesh=mesh, elementshape=shape, value=self.coeff)
 
         projectedCoefficients = self.coeff * mesh._orientedAreaProjections
 
         return projectedCoefficients.sum(0)
-        
+
     def _getWeight(self, var, transientGeomCoeff=None, diffusionGeomCoeff=None):
         r"""
         Testing that the sign of the equation is taken into account
@@ -150,11 +119,11 @@ class _AbstractConvectionTerm(FaceTerm):
         ...  - ConvectionTerm(coeff=[[1]])
         ...  - ImplicitSourceTerm(coeff=m.x)).solve(v, dt=1.)
 
-        >>> print numerix.allclose(v, v0)
+        >>> print(numerix.allclose(v, v0))
         True
-        
+
         """
-                
+
         if self.stencil is None:
 
             geomCoeff = self._getGeomCoeff(var)
@@ -169,7 +138,7 @@ class _AbstractConvectionTerm(FaceTerm):
                 diffCoeff = diffusionGeomCoeff[0].numericValue
                 diffCoeff = diffCoeff - (diffCoeff == 0) * geomCoeff / pecletLarge
                 peclet = -geomCoeff / diffCoeff
-                    
+
             alpha = self._alpha(peclet)
 
             self.stencil = {'implicit' : {'cell 1 diag'    : alpha,
@@ -180,14 +149,14 @@ class _AbstractConvectionTerm(FaceTerm):
         return self.stencil
 
     def _checkVar(self, var):
-        FaceTerm._checkVar(self, var)  
+        FaceTerm._checkVar(self, var)
         if not (isinstance(self.coeff, FaceVariable) and self.coeff.rank == 1):
             coeffShape = numerix.getShape(self.coeff)
             if (coeffShape is ()) or (coeffShape[0] != var.mesh.dim):
                 raise VectorCoeffError
 
     def _buildMatrix(self, var, SparseMatrix, boundaryConditions=(), dt=None, transientGeomCoeff=None, diffusionGeomCoeff=None):
-        
+
         var, L, b = FaceTerm._buildMatrix(self, var, SparseMatrix, boundaryConditions=boundaryConditions, dt=dt, transientGeomCoeff=transientGeomCoeff, diffusionGeomCoeff=diffusionGeomCoeff)
 
 ##        if var.rank != 1:
@@ -196,8 +165,6 @@ class _AbstractConvectionTerm(FaceTerm):
 
         if (not hasattr(self, 'constraintL')) or (not hasattr(self, 'constraintB')):
 
-            constraintMask = var.faceGrad.constraintMask | var.arithmeticFaceValue.constraintMask
-
             weight = self._getWeight(var, transientGeomCoeff, diffusionGeomCoeff)
 
             if 'implicit' in weight:
@@ -205,24 +172,107 @@ class _AbstractConvectionTerm(FaceTerm):
             else:
                 alpha = 0.0
 
-            exteriorCoeff =  self.coeff * mesh.exteriorFaces
+            alpha_constraint = numerix.where(var.faceGrad.constraintMask, 1.0, alpha)
+
+            def divergence(face_value):
+                return (
+                    face_value * \
+                    (var.faceGrad.constraintMask | var.arithmeticFaceValue.constraintMask) * \
+                    self.coeff * mesh.exteriorFaces
+                ).divergence * mesh.cellVolumes
+
+            self.constraintL = divergence(alpha_constraint)
+            dvar = (var.faceGrad * mesh._cellDistances * mesh.faceNormals).sum(axis=0)
+            self.constraintB = divergence(
+                (alpha_constraint - 1) * var.arithmeticFaceValue + (alpha - 1)  * dvar * var.faceGrad.constraintMask
+            )
 
-            self.constraintL = (alpha * constraintMask * exteriorCoeff).divergence * mesh.cellVolumes
-            self.constraintB =  -((1 - alpha) * var.arithmeticFaceValue * constraintMask * exteriorCoeff).divergence * mesh.cellVolumes
 
         ids = self._reshapeIDs(var, numerix.arange(mesh.numberOfCells))
-        L.addAt(numerix.array(self.constraintL).ravel(), ids.ravel(), ids.swapaxes(0,1).ravel())
+        L.addAt(numerix.array(self.constraintL).ravel(), ids.ravel(), ids.swapaxes(0, 1).ravel())
         b += numerix.reshape(self.constraintB.value, ids.shape).sum(0).ravel()
 
         return (var, L, b)
 
-class __ConvectionTerm(_AbstractConvectionTerm): 
+
+    def _test(self):
+        """Test cases for convection with constraints.
+
+        The following tests both a Dirichlet and a Neumann type
+        boundary condition with convection using constraints. It
+        checks that the Neumann boundary condition converges without
+        multiple iterations of the solve step. The Dirichlet boundary
+        condition is second order accurate. The Neumann is only first
+        order accurate. These tests were prompted by
+        https://github.com/usnistgov/fipy/pull/714.
+
+        >>> import fipy as fp
+        >>> import numpy as np
+
+        Test Dirichlet boundary condition with a fixed value on the
+        left and a fixed value on the right. Check that the order of
+        accuracy is 2.
+
+
+        >>> nx0 = 64
+        >>> mesh = fp.Grid1D(nx=nx0, dx=1. / nx0)
+        >>> var = fp.CellVariable(mesh)
+        >>> var.constrain(1.0, mesh.facesLeft)
+        >>> var.constrain(0.0, mesh.facesRight)
+        >>> eqn = fp.CentralDifferenceConvectionTerm((1.0,)) - fp.DiffusionTerm()
+        >>> _ = eqn.sweep(var, solver=fp.LinearLUSolver())
+        >>> expected =  (np.exp(mesh.x) - np.exp(1.)) / (1 - np.exp(1.))
+        >>> error0 = float(np.sqrt(((var.value - expected)**2 * mesh.dx).sum()))
+
+        >>> nx1 = 128
+        >>> mesh = fp.Grid1D(nx=nx1, dx=1. / nx1)
+        >>> var = fp.CellVariable(mesh)
+        >>> var.constrain(1.0, mesh.facesLeft)
+        >>> var.constrain(0.0, mesh.facesRight)
+        >>> eqn = fp.CentralDifferenceConvectionTerm((1.0,)) - fp.DiffusionTerm()
+        >>> _ = eqn.sweep(var, solver=fp.LinearLUSolver())
+        >>> expected =  (np.exp(mesh.x) - np.exp(1.)) / (1 - np.exp(1.))
+        >>> error1 = float(np.sqrt(((var.value - expected)**2 * mesh.dx).sum()))
+
+        >>> assert np.allclose(np.log(error1 / error0 ) / np.log(nx0 / nx1), 2.0, atol=0.02)
+
+        Test Neumann boundary condition with a fixed value on the left
+        and a gradient on the right. Check that the order of accuracy
+        is 1.
+
+        >>> dphi = 1.0
+
+        >>> nx0 = 64
+        >>> mesh = fp.Grid1D(nx=nx0, dx=1. / nx0)
+        >>> var = fp.CellVariable(mesh)
+        >>> var.constrain(1.0, mesh.facesLeft)
+        >>> _  = var.faceGrad.constrain([dphi], mesh.facesRight),
+        >>> eqn = fp.CentralDifferenceConvectionTerm((1.0,)) - fp.DiffusionTerm()
+        >>> _ = eqn.sweep(var, solver=fp.LinearLUSolver())
+        >>> expected = 1 + dphi * (np.exp(mesh.x) - 1) / np.exp(1.)
+        >>> error0 = float(np.sqrt(((var.value - expected)**2 * mesh.dx).sum()))
+
+        >>> nx1 = 128
+        >>> mesh = fp.Grid1D(nx=nx1, dx=1. / nx1)
+        >>> var = fp.CellVariable(mesh)
+        >>> var.constrain(1.0, mesh.facesLeft)
+        >>> _ = var.faceGrad.constrain([dphi], mesh.facesRight),
+        >>> eqn = fp.CentralDifferenceConvectionTerm((1.0,)) - fp.DiffusionTerm()
+        >>> _ = eqn.sweep(var, solver=fp.LinearLUSolver())
+        >>> expected = 1 + dphi * (np.exp(mesh.x) - 1) / np.exp(1.)
+        >>> error1 = float(np.sqrt(((var.value - expected)**2 * mesh.dx).sum()))
+
+        >>> assert np.allclose(np.log(error1 / error0 ) / np.log(nx0 / nx1), 1.0, atol=0.002)
+
+        """
+
+class __ConvectionTerm(_AbstractConvectionTerm):
     """
     Dummy subclass for tests
     """
-    pass 
+    pass
 
-def _test(): 
+def _test():
     import fipy.tests.doctestPlus
     return fipy.tests.doctestPlus.testmod()
 
