@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 # Dictionary containing numbers
 #
 # These objects are meant to be used like arrays with generalized
@@ -8,6 +9,7 @@
 # last revision: 1999-7-23
 #
 
+from builtins import str
 __all__ = []
 
 from fipy.tools.dimensions import DictWithDefault
@@ -16,15 +18,13 @@ class _NumberDict(DictWithDefault._DictWithDefault):
 
     """Dictionary storing numerical values
 
-    Constructor: _NumberDict()
-
     An instance of this class acts like an array of number with
     generalized (non-integer) indices. A value of zero is assumed
-    for undefined entries. _NumberDict instances support addition,
-    and subtraction with other _NumberDict instances, and multiplication
+    for undefined entries. `_NumberDict` instances support addition,
+    and subtraction with other `_NumberDict` instances, and multiplication
     and division by scalars.
     """
-    
+
     def __init__(self):
         DictWithDefault._DictWithDefault.__init__(self, 0)
 
@@ -35,7 +35,7 @@ class _NumberDict(DictWithDefault._DictWithDefault):
         return repr(self.data)
 
     def __coerce__(self, other):
-        if type(other) == type({}):
+        if isinstance(other, type({})):
             new = _NumberDict()
             new.data = other
             other = new
@@ -43,9 +43,9 @@ class _NumberDict(DictWithDefault._DictWithDefault):
 
     def __add__(self, other):
         sum = _NumberDict()
-        for key in self.keys():
+        for key in list(self.keys()):
             sum[key] = self[key]
-        for key in other.keys():
+        for key in list(other.keys()):
             sum[key] = sum[key] + other[key]
         return sum
 
@@ -53,9 +53,9 @@ class _NumberDict(DictWithDefault._DictWithDefault):
 
     def __sub__(self, other):
         sum = _NumberDict()
-        for key in self.keys():
+        for key in list(self.keys()):
             sum[key] = self[key]
-        for key in other.keys():
+        for key in list(other.keys()):
             sum[key] = sum[key] - other[key]
         return sum
 
@@ -70,7 +70,7 @@ class _NumberDict(DictWithDefault._DictWithDefault):
 
     def __mul__(self, other):
         new = _NumberDict()
-        for key in self.keys():
+        for key in list(self.keys()):
             new[key] = other*self[key]
         return new
 
@@ -78,8 +78,8 @@ class _NumberDict(DictWithDefault._DictWithDefault):
 
     def __floordiv__(self, other):
         new = _NumberDict()
-        for key in self.keys():
+        for key in list(self.keys()):
             new[key] = self[key]//other
         return new
 
-    __div__ = __floordiv__
\ No newline at end of file
+    __div__ = __floordiv__
